import {
  select,
  csv,
  pie,
  arc,
  scaleOrdinal,
  schemeCategory10,
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');


//Define the number format in legend
const numberFormat = number =>
  	(number)  ;


//Define pie chart structure
const render = data => {
  const pieData = pie().sort(null).value(d=>d.TotalLibrarySize)(data);
  const colors = scaleOrdinal(schemeCategory10);
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(200)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.TotalLibrarySize))
  	.on("mouseover", d => console.log(d.data.TotalLibrarySize));
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  
  
//Define legend
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.TotalLibrarySize));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.Country);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>numberFormat(d.data.TotalLibrarySize));
}


//Democrat population csv
const csvUrl =
 'https://gist.githubusercontent.com/yaswanthsen/e50d812b7c2bbde6a869ca7f6a708bb4/raw/00fee7cb619e0d6bf00f529191ac76971d769658/HBO.MAX.csv';


//Load the data and select top 10 entries 
csv(csvUrl).then(csvData => {
    csvData.sort((data1, data2) => data2.TotalLibrarySize-data1.TotalLibrarySize);
    if (csvData) {
      render(csvData.slice(0, 10));
    }
});